# frozen_string_literal: true

require_relative 'initializer'
require_relative 'configuration'
require_relative 'formatters/swift_format_formatter'
require_relative 'formatters/swift_lint_formatter'
require_relative 'formatters/clang_format_formatter'
require 'thor'

module CodeFormatter
  class CLI < Thor
    desc 'init', 'initialize config'
    def init
      Initializer.init
    end

    desc 'format', 'format code with configuration'
    option :config, default: Initializer.initialized_config, aliases: '-c', type: :string, desc: 'configuration file'
    option :path, default: Dir.pwd, aliases: '-p', type: :string, desc: 'destination path'
    option :force_all, default: false, aliases: '-fa', type: :boolean, desc: 'force all files to format'
    def format
      config = Configuration.load_from(options[:config])
      force_all = options[:force_all]
      path = options[:path]
      formatters = [
        SwiftFormatFormatter.new(config, path),
        SwiftLintFormatter.new(config, path),
        ClangFormatFormatter.new(config, path)
      ]
      formatters.each { |f| f&.format(force_all) }
    end
  end
end
