# frozen_string_literal: true

module CodeFormatter
  class Configuration
    attr_accessor :included_files
    attr_accessor :excluded_files
    attr_accessor :source_file

    def initialize
      self.included_files = []
      self.excluded_files = []

      yield self if block_given?
    end

    # @param [String] file
    # @return [Configuration]
    def self.load_from(file)
      return unless file || File.file?(file)

      begin
        config = eval(File.read(file), binding, 'config loading problem')
        config.source_file = file
        return config if config.is_a? Configuration

        warn "[#{file}] isn't a CodeFormatter::Configuration, but #{config.class}."
      rescue SyntaxError, StandardError => e
        warn "Invalid configuration in [#{file}]: #{e}"
      end
    end
  end
end
