# frozen_string_literal: true

require_relative 'formatter'
require 'yaml'

module CodeFormatter
  class ClangFormatFormatter < Formatter
    def format_files(files)
      `clang-format -i -style="#{style_dump}" #{files.join(' ')}`
    end

    def shell_command
      'clang-format'
    end

    def files_filter
      "'*.h' '*.m' '*.mm' '*.c' '*.cpp'"
    end

    private

    def style_dump
      style_yaml.to_s.gsub('=>', ' : ')
    end

    def style_yaml
      file = File.expand_path('../../resources/clang_format_style.yml', __FILE__)
      YAML.load_file(file)
    end
  end
end
