# frozen_string_literal: true

require_relative 'formatter'
require 'yaml'

module CodeFormatter
  class SwiftFormatFormatter < Formatter
    def format_files(files)
      disabled = disabled_rules.join(',')
      enabled = enabled_rules.join(',')
      `swiftformat #{files.join(' ')} --disable #{disabled} --enable #{enabled}`
    end

    def shell_command
      'swiftformat'
    end

    def files_filter
      "'*.swift'"
    end

    private

    # @return [[String]] enabled rules
    def enabled_rules
      rules_config['enabled_rules'].map(&:strip)
    end

    # @return [[String]] disabled rules
    def disabled_rules
      rules_config['disabled_rules'].map(&:strip)
    end

    def rules_config
      rules_file = File.expand_path('../../resources/swiftformat_rules.yml', __FILE__)
      YAML.load_file(rules_file)
    end
  end
end
