# frozen_string_literal: true

require_relative 'formatter'
require 'yaml'
require 'tempfile'

module CodeFormatter
  class SwiftLintFormatter < Formatter
    def format_files(_)
      create_config do |file|
        system("swiftlint autocorrect --path #{path} --config #{file.path}")
        system("swiftlint --path #{path} --config #{file.path}")
      end
    end

    def shell_command
      'swiftlint'
    end

    def files_filter
      "'*.swift'"
    end

    private

    def create_config
      file = Tempfile.new(%w[swiftlint .yml])
      begin
        file.write(swiftlint_config)
        file.close
        yield file if block_given?
      ensure
        file.unlink
      end
    end

    def swiftlint_config
      rules_file = File.expand_path('../../resources/swiftlint.yml', __FILE__)
      yaml_hash = YAML.load_file(rules_file)
      yaml_hash['included'] = config.included_files
      yaml_hash['excluded'] = config.excluded_files
      yaml_hash.to_yaml
    end
  end
end
